
(*

This applet checks if your system requires a fix of the known StdCLib bug found
on some MacOS X 10.4 Intel systems discovered by the FBtoC Development
Team.

If the file "/System/Library/CFMSupport/StdCLib" exists without a valid FileType
of "shlb", problems or crashes can occur when executing
programs that require this file to have correct FileType code.

This applet checks to see if the correct FileType of "shlb"
exists for the file "/System/Library/CFMSupport/StdCLib". If it does not, it attempts
to duplicate the file and make it available to all Users by placing the file in the
location "/Library/CFMSupport/StdCLib". Alternatively, if it should be only available
to the present User, change the first line from "set FixAllUsers to true" shown
below to read "set FixAllUsers to false". The duplicate file will then be placed in the
User's home folder at the location "~/Library/CFMSupport/StdCLib".

*)


(* Specify if Fix applies to this User or All Users or not *)
set FixAllUsers to true


tell application "Finder"
	
	(* Inform User of the purpose of this applet *)
	display dialog "This applet checks if your system requires a fix of a known StdCLib bug found on some MacOS X 10.4 Intel systems." buttons {"Cancel", "OK"} default button 2
	
	if the button returned of the result is "OK" then
		
		(* Users wishes the Fix to be applied *)
		
		(* Initally assume no Fix is required *)
		set NeedsFixing to false
		
		(* Check the file to see if bug is present *)
		set MySource to file "StdCLib" of folder "CFMSupport" of folder "Library" of folder "System" of startup disk
		
		(* Obtain the file type and check if it is "shlb" *)
		copy file type of MySource as string to FileType
		if FileType is not "shlb" then
			set NeedsFixing to true
		end if
		
		if NeedsFixing is true then
			
			(* Needs to be fixed so check if a Fix has already been applied *)
			
			(* Obtain current User name *)
			set MyName to do shell script "whoami"
			
			(* Initally assume Fix is installed *)
			set FixInstalled to true
			
			(* Check the file to see if Fixed file is present *)
			try
				if FixAllUsers is true then
					set MyFix to file "StdCLib" of folder "CFMSupport" of folder "Library" of startup disk
				else
					set MyFix to file "StdCLib" of folder "CFMSupport" of folder "Library" of folder MyName of folder "Users" of startup disk
				end if
			on error
				set FixInstalled to false
			end try
			
			(* Check the Fixed file to see if it is correctly applied *)
			if FixInstalled is true then
				
				(* Initally assume Fix is correctly installed *)
				set FixedCorrectly to true
				
				(* Obtain the file type and check if it is "shlb" *)
				copy file type of MyFix as string to FileType
				if FileType is not "shlb" then
					set FixedCorrectly to false
				end if
				
				(* Identify if Fix adequately applied *)
				if FixedCorrectly is true then
					
					(* Correctly applied so no Fix is necessary *)
					set NeedsFixing to false
					
					(* Inform User that Fix already applied *)
					display dialog "A previous fix has been found and appears to be correct" buttons {"OK"} default button 1
					
				else
					
					(* Not correctly applied so delete bad Fix *)
					try
						if FixAllUsers is true then
							do shell script "rm /Library/CFMSupport/StdCLib"
						else
							do shell script "rm ~/Library/CFMSupport/StdCLib"
						end if
					on error
						display dialog "Sorry, an error occurred because a previous fix could not be corrected"
					end try
					
				end if
				
			else
				
				(* Fix is not installed *)
				set NeedsFixing to true
				
			end if
			
		end if
		
		(* Inform user on whether Fix is required or not *)
		if NeedsFixing is true then
			
			(* System does require a Fix to be performed *)
			display dialog "Your system requires to be fixed. Shall I fix it?" buttons {"Cancel", "OK"} default button 2
			
			if the button returned of the result is "OK" then
				
				(* Perform the Fix to the System *)
				
				(* Obtain current User name *)
				set MyName to do shell script "whoami"
				
				(* Create folder "CFMSupport" in User's Library folder only if it does not presently exist *)
				try
					if FixAllUsers is true then
						do shell script "mkdir /Library/CFMSupport"
					else
						do shell script "mkdir ~/Library/CFMSupport"
					end if
				end try
				
				(* Define the file that is to be duplicated *)
				set MySource to file "StdCLib" of folder "CFMSupport" of folder "Library" of folder "System" of startup disk
				
				(* Specify where the file should go *)
				if FixAllUsers is true then
					set MyDest to folder "CFMSupport" of folder "Library" of startup disk
				else
					set MyDest to folder "CFMSupport" of folder "Library" of folder MyName of folder "Users" of startup disk
				end if
				
				(* Perform the file duplication *)
				duplicate MySource to MyDest
				
				(* Locate the newly created duplicate file *)
				
				if FixAllUsers is true then
					set MyFile to file "StdCLib" of folder "CFMSupport" of folder "Library" of startup disk
				else
					set MyFile to file "StdCLib" of folder "CFMSupport" of folder "Library" of folder MyName of folder "Users" of startup disk
				end if
				
				(* Set the File Type of the new duplicate file to "shlb" *)
				set file type of MyFile to "shlb"
				
				(* Set the File Creator of the new duplicate file to "MACS" *)
				set creator type of MyFile to "MACS"
				
				(* Inform User that Fix has been applied *)
				display dialog "Your system has been fixed" buttons {"OK"} default button 1
				
			end if
			
		else
			
			(* Inform User that Fix not required *)
			display dialog "Your system does not need to be fixed" buttons {"OK"} default button 1
			
		end if
		
	else
		
		(* User does not wish for the Fix to be applied *)
		
	end if
	
end tell
